#
# spec file for package libuninameslist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 1
Name:           libuninameslist
Version:        20240524
Release:        1.3
Summary:        A library providing Unicode character names and annotations
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://github.com/fontforge/libuninameslist
Source0:        https://github.com/fontforge/libuninameslist/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libuninameslist provides Unicode name and annotation data from the official Unicode Character Database.

%package     -n %{name}%{somajor}
Summary:        A library providing Unicode character names and annotations
Group:          System/Libraries

%description -n %{name}%{somajor}
libuninameslist provides Unicode name and annotation data from the official Unicode Character Database.

%package        devel
Summary:        Header files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name}%{somajor} = %{version}

%description    devel
This package contains header files for %{name}.

%prep
%setup -q

%build
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{name}%{somajor} -p /sbin/ldconfig
%postun -n %{name}%{somajor} -p /sbin/ldconfig

%files -n libuninameslist%{somajor}
%license LICENSE
%{_libdir}/libuninameslist.so.%{somajor}*

%files devel
%{_libdir}/libuninameslist.so
%{_libdir}/pkgconfig/libuninameslist.pc
%{_mandir}/man3/libuninameslist.3%{?ext_man}
%{_includedir}/uninameslist.h

%changelog
* Tue Jul 30 2024 pgajdos@suse.com
- version update to 20240524
  * Version 1.14, Unicode 15.1 and French version 1.7 now is at 15.1.
* Mon Sep 18 2023 Dirk Müller <dmueller@suse.com>
- update to 20230916:
  * This release contains source code to build libuninameslist
    (with NamesList.txt 15.1), libuninameslist-fr (with
    ListeDesNoms 15.0), and Python wrapper uninameslist.py
    (ver0.2).
  * Version 15.1 is a minor update, adding 627 characters,
    bringing the total to 149,813 characters.
  * Details about 15.1 can be found here:
    http://blog.unicode.org/2023/09/announcing-unicode-standard-
    version-151.html
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 20230523:
  * This release is marked as 15.0b for testing purposes and
    contains 608 new characters.
  * If you have comments about this library, please create an
  * The French libuninameslist-fr is also now updated from 14.0
    to 15.0.
  * Users who do not have 'autoconf' or 'automake' (or cannot run
    them), should choose the -dist- release version included here
    which skips these steps (you then start at ./configure).
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 20221022:
  * This release contains source code to build libuninameslist (with
    NamesList.txt 15.0), libuninameslist-fr (with ListeDesNoms 14.0), and
    Python wrapper uninameslist.py (ver0.2).
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 20220701:
  * Unicode 15.0_Beta (Nameslist.txt 15_Beta for review until Jul12).
  * Biswapriyo Nath added Windows MSYS2 build (used by github tests),
  this also helped identify some more nameslist-dll.h clang fixes.
  * orbea fixed Makefile.am bug fixing Gentoo Bugs 779670 and 792474.
* Sat Nov 27 2021 Dirk Müller <dmueller@suse.com>
- update to 20211114:
  * Version 1.10, Unicode 14.0 and French version 1.5 now is at 14.0.
  * Gentoo Bug 781716 & Debian Bug 989173, -O0 patch by Naohiro Aota.
* Sat Nov 13 2021 Dirk Müller <dmueller@suse.com>
- update to 20210917:
  * Version 1.9, Unicode 14.0. French version 1.4 is at Unicode 13.1.
    Unicode has changed cadence to release later for this year. This
    contains Official 14.0 NamesList.txt codes released on 2021sep14.
    Unicode 14.0 adds 838 characters for total of 144,697 characters.
    Several edits, and improvements were added to the French library.
  * Unicode 14.0_Beta (Nameslist.txt 14_Beta for review until Jul08).
  * PR#24 "Remove .libs from linker paths". Bug found using slibtool.
  * Add code to reduce need for 'make clean' after ./configure steps.
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 20200505:
  * Version 1.7, Unicode 13.0, French version 1.3 is at Unicode 13.0,
    and including python library wrapper 'uninameslist', version 0.2.
    The French version was updated from version 10.0 to 13.0 shortly
    after Unicode's release - this is a big effort and congratulation
    to the French team! This version updates the main library to also
    include access to libuninameslist-fr. To include this access, you
    need to use './configure --enable-frenchlib'
    This is the first step in adding other languages if anyone wants
    to add more languages.
    The default functions remain as English to retain common grounds
    which is necessary for scripting, and/or file-sharing purposes.
  * Version 1.5, Unicode 12.1, French version 1.2 is at Unicode 10.0.
    Contains Official 12.1 codes.
  * Version 1.4, Unicode 12.1, French version 1.2 is at Unicode 10.0.
    Not completely 12.1.0, created too early before official version
    was announced later in month. This version contains beta 12.1.0d1
  * Version 1.3, Unicode 11.0, French version 1.2 is at Unicode 10.0.
  * Library internal definitions personalized to allow more than one
    library to be loaded at a time. Base library maintains same names
    for backwards compatibility with older programs.
  * Optional python wrapper available for directly accessing library.
    Use python's pip to install wrapper (requires pip and wheel).
  * Unicode 11.0_Beta (Nameslist.txt 11_Beta for review until Apr23).
  * Added Python wrapper and names2 functions.
  * Version 1.2, Unicode 10.0, French version is now also 10.0.0.
  * Added function calls to French version to allow use of one or more
    libraries at the same (Dynamic library linking needs testing since
    added 'FR' may be issue with older programs expecting same name).
  * Added more "make check" to include checking French library.
  * Version 1.1, Unicode 10.0, French version is 7.0(2014-06-22).
  * Added "make check" to allow for automatic library test and verify.
  * Unicode 10.0_Beta (Nameslist.txt 10_Beta for review until Apr30).
  * Version 1.0, Unicode 9.0, French version is 7.0(2014-06-22).
  * Corrected library to report correctly as next version up. This is
    probably a significant change, therefore bumped both libraries to
    start at 1.0 even though backwards compatibility remains the same,
    otherwise would have become version_0.6 (and French version_0.4).
  * Removed the excessively long package name, which you'll note as a
    so-bump change with Fedora and also Debian in naming this package.
  * Version 0.5. Unicode 8.0. French version is 7.0(2014-06-22).
* Tue Nov 14 2017 dimstar@opensuse.org
- Add pkgconfig BuildRequires: allow the rpm dep generator to
  inspect the shipped .pc file and produce requires/provides.
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.4.20140731
  * Unicode 7.0.
  * Updated French version to 7.0
- Update home Url and download source URLs to news home project
- Add autoconf, automake and libtool require; needed to generate
  configure script
* Fri Jan  4 2013 dmitry_r@opensuse.org
- Initial package, version 20091231
